==> pegasus-support-1.6.9-sources.jar: com/thebeastshop/support/vo/benefit/ReminderVO.java <==
package com.thebeastshop.support.vo.benefit;

import com.thebeastshop.support.enums.benefit.ReminderTypeEnum;

import java.io.Serializable;

/**
 * 特权提醒对象
 * Created by feilong.gao on 2017/4/17.
 */
public class ReminderVO implements Serializable {
    private static final long serialVersionUID = -5830582527456478290L;
    // 提示名称
    private String name;
    // 提示类型
    private ReminderTypeEnum Type;
    //提示按钮文本
    private String btnText;
    //跳转链接
    private String link;
    //link类型
    private String linkType;
    //特权id
    private Integer benefitId;

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public ReminderTypeEnum getType() {
        return Type;
    }

    public void setType(ReminderTypeEnum type) {
        Type = type;
    }

    public String getBtnText() {
        return btnText;
    }

    public void setBtnText(String btnText) {
        this.btnText = btnText;
    }

    public String getLink() {
        return link;
    }

    public void setLink(String link) {
        this.link = link;
    }

    public String getLinkType() {
        return linkType;
    }

    public void setLinkType(String linkType) {
        this.linkType = linkType;
    }

    public Integer getBenefitId() {
        return benefitId;
    }

    public void setBenefitId(Integer benefitId) {
        this.benefitId = benefitId;
    }

    @Override
    public String toString() {
        final StringBuffer sb = new StringBuffer("ReminderVO{");
        sb.append("name='").append(name).append('\'');
        sb.append(", Type=").append(Type);
        sb.append(", btnText='").append(btnText).append('\'');
        sb.append(", link='").append(link).append('\'');
        sb.append(", benefitId=").append(benefitId);
        sb.append('}');
        return sb.toString();
    }
}

==> pegasus-support-2.0.5-sources.jar: com/thebeastshop/support/vo/benefit/ReminderVO.java <==
package com.thebeastshop.support.vo.benefit;

import com.thebeastshop.support.enums.benefit.ReminderTypeEnum;
import org.apache.commons.lang3.builder.ToStringBuilder;

import java.io.Serializable;

/**
 * 特权提醒对象
 * Created by feilong.gao on 2017/4/17.
 */
public class ReminderVO implements Serializable {
    private static final long serialVersionUID = -5830582527456478290L;
    // 提示名称
    private String name;
    // 名字提醒
    private String nameTip;
    // 提示类型
    private ReminderTypeEnum Type;
    //提示按钮文本
    private String btnText;
    //跳转链接
    private String link;
    //小程序跳转链接
    private String mpLink;
    //link类型
    private String linkType;
    //特权id
    private Integer benefitId;

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getNameTip() {
        return nameTip;
    }

    public void setNameTip(String nameTip) {
        this.nameTip = nameTip;
    }

    public ReminderTypeEnum getType() {
        return Type;
    }

    public void setType(ReminderTypeEnum type) {
        Type = type;
    }

    public String getBtnText() {
        return btnText;
    }

    public void setBtnText(String btnText) {
        this.btnText = btnText;
    }

    public String getLink() {
        return link;
    }

    public void setLink(String link) {
        this.link = link;
    }

    public String getMpLink() {
        return mpLink;
    }

    public void setMpLink(String mpLink) {
        this.mpLink = mpLink;
    }

    public String getLinkType() {
        return linkType;
    }

    public void setLinkType(String linkType) {
        this.linkType = linkType;
    }

    public Integer getBenefitId() {
        return benefitId;
    }

    public void setBenefitId(Integer benefitId) {
        this.benefitId = benefitId;
    }

    @Override
    public String toString() {
        return new ToStringBuilder(this)
                .append("name", name)
                .append("nameTip", nameTip)
                .append("Type", Type)
                .append("btnText", btnText)
                .append("link", link)
                .append("mpLink", mpLink)
                .append("linkType", linkType)
                .append("benefitId", benefitId)
                .toString();
    }
}
